import {Plugin} from 'ckeditor5/src/core';
import DivManagerCommand from "./divmanagercommand";

/**
 * This file has the logic for defining the divManager model, and for how it is
 * CONVERTED to standard DOM markup.
 */
export default class DivManagerEditing extends Plugin {
  init() {
    this._defineSchema();
    this._defineConverters();
    this.editor.commands.add(
      'addDiv', new DivManagerCommand(this.editor)
    );
  }

  _defineSchema() {
    const schema = this.editor.model.schema;

    schema.register('divContent', {
      inheritAllFrom: '$inlineObject',
      allowContentOf: '$root',
      allowAttributes: ['class', 'title', 'id', 'lang', 'style'],
    });
  }

  _defineConverters() {
    const conversion = this.editor.conversion;

    // model->view
    conversion.for('upcast').elementToElement({
      model: 'divContent',
      view: {
        name: 'div',
        classes: 'simple-grid',
      }
    });

    conversion.for('downcast').elementToElement({
      model: 'divContent',
      view: (modelElement, {writer: viewWriter}) => {
        const attr = getAttrsData(modelElement);
        return viewWriter.createContainerElement('div', attr);
      }
    });
  }
}

function getAttrsData(modelItem) {
  let currentAttributes = {};
  modelItem._attrs.forEach((value, key) => {
    if (value) {
      currentAttributes[key] = value;
    }
  });
  return currentAttributes;
}
