import {
  View,
  LabeledFieldView,
  createLabeledInputText,
  ButtonView,
  submitHandler,
} from 'ckeditor5/src/ui';
import { icons } from 'ckeditor5/src/core';

// cSpell:ignore divmanagerview

export default class DivManagerView extends View {
  constructor(locale) {
    super(locale);

    this.textInputView = this._createInput('Content');
    this.idInputView = this._createInput( 'ID' );
    this.classInputView = this._createInput( 'Stylesheet class name' );
    this.langcodeInputView = this._createInput( 'Language Code' );
    this.styleInputView = this._createInput( 'Raw style for div' );
    this.titleInputView = this._createInput( 'Advisory title' );

    this.saveButtonView = this._createButton('Save', icons.check, 'ck-button-save');
    this.saveButtonView.type = 'submit';
    this.cancelButtonView = this._createButton( 'Cancel', icons.cancel, 'ck-button-cancel' );
    this.cancelButtonView.delegate( 'execute' ).to( this, 'cancel' );

    this.childViews = this.createCollection( [
      this.textInputView,
      this.idInputView,
      this.classInputView,
      this.langcodeInputView,
      this.styleInputView,
      this.titleInputView,
      this.saveButtonView,
      this.cancelButtonView
    ] );

    this.setTemplate( {
      tag: 'form',
      attributes: {
        class: [ 'ck', 'ck-div-form' ],
        tabindex: '-1'
      },
      children: this.childViews
    });
  }

  render() {
    super.render();

    // Submit the form when the user clicked the save button or pressed enter in the input.
    submitHandler( {
      view: this
    } );
  }

  focus() {
    // If the text field is enabled, focus it.
    if ( this.textInputView.isEnabled ) {
      this.textInputView.focus();
    }
    else {
      this.titleInputView.focus();
    }
  }

  _createInput(label) {
    const labeledInput = new LabeledFieldView( this.locale, createLabeledInputText );
    labeledInput.label = label;
    return labeledInput;
  }

  _createButton( label, icon, className ) {
    const button = new ButtonView();

    button.set( {
      label,
      icon,
      tooltip: true,
      class: className
    } );

    return button;
  }
}
